@@ -94,9 +94,9 @@ def update_documentation(rules):
 
         # Add the rules
         new_file.write(
-            'The following **{}** rules are applied by this linter:\n'.format(len(sorted_rules)))
+            '(_This documentation is generated by running `cfn-lint --update-documentation`, do not alter this manually_)\n\n')
         new_file.write(
-            '(_This documentation is generated from the Rules, do not alter this manually_)\n\n')
+            'The following **{}** rules are applied by this linter:\n\n'.format(len(sorted_rules) + 3))
         new_file.write(
             '| Rule ID  | Title | Description | Config<br />(Name:Type:Default) | Source | Tags |\n')
         new_file.write('| -------- | ----- | ----------- | ---------- | ------ | ---- |\n')
@@ -104,20 +104,9 @@ def update_documentation(rules):
         rule_output = '| {0}<a name="{0}"></a> | {1} | {2} | {3} | [Source]({4}) | {5} |\n'
 
         # Add system Errors (hardcoded)
-        parseerror = cfnlint.rules.ParseError()
-        tags = ','.join('`{0}`'.format(tag) for tag in parseerror.tags)
-        new_file.write(rule_output.format(
-            parseerror.id, parseerror.shortdesc, parseerror.description, '', '', tags))
-
-        transformerror = cfnlint.rules.TransformError()
-        tags = ','.join('`{0}`'.format(tag) for tag in transformerror.tags)
-        new_file.write(rule_output.format(
-            transformerror.id, transformerror.shortdesc, transformerror.description, '', '', tags))
-
-        ruleerror = cfnlint.rules.RuleError()
-        tags = ','.join('`{0}`'.format(tag) for tag in ruleerror.tags)
-        new_file.write(
-            rule_output.format(ruleerror.id, ruleerror.shortdesc, ruleerror.description, '', '', tags))
+        for error in [cfnlint.rules.ParseError(), cfnlint.rules.TransformError(), cfnlint.rules.RuleError()]:
+            tags = ','.join('`{0}`'.format(tag) for tag in error.tags)
+            new_file.write(rule_output.format(error.id, error.shortdesc, error.description, '', '', tags))
 
         # Seprate the experimental rules
         experimental_rules = []
@@ -157,7 +146,7 @@ def patch_spec(content, region):
         filenames.sort()
         for filename in fnmatch.filter(filenames, '*.json'):
             file_path = os.path.basename(filename)
-            module = dirpath.replace('%s' % append_dir, '%s' % region).replace('/', '.')
+            module = dirpath.replace('%s' % append_dir, '%s' % region).replace(os.path.sep, '.')
             LOGGER.info('Processing %s/%s', module, file_path)
             all_patches = jsonpatch.JsonPatch(cfnlint.helpers.load_resource(
                 'cfnlint.data.ExtendedSpecs.{}'.format(module), file_path))
